<template>
  <zt-table-wraper ref="tableObj" v-slot="{ table }" :lazy="true" :paging="true" delete-url="/workflowConfig"
                           query-url="/workflowConfig/getRoleByWorkflowSteps">
                <el-form :inline="true" :model="dataForm" @keyup.enter.native="table.query()">
                  <el-form-item>
                    <el-button class="form-title" type="text">选中流程步骤审核用户角色</el-button>
                  </el-form-item>
                  <el-form-item style="margin-left: 10px">
                    <zt-button v-show="selectedWorkflowConfigFlag" type="primary" @click="addRole(dataForm.id)">添加角色
                    </zt-button>
                  </el-form-item>
                  <el-form-item>
                    <zt-button v-show="selectedWorkflowConfigFlag" type="delete" @click="deleteHandle()"/>
                  </el-form-item>

                </el-form>
                <el-table ref="table" v-loading="table.dataLoading" :data="table.dataList"
                          border
                          height="100"
                          v-adaptive="{bottomOffset:70}"
                          highlight-current-row row-key="id"
                           @selection-change="table.selectionChangeHandle">
                  <el-table-column align="center" type="selection" width="60"/>
                  <el-table-column label="角色名称" prop="roleName" width="150px"/>
                  <el-table-column label="单位名称" prop="companyName"/>
                </el-table>
            <!-- 弹窗, 新增 / 修改 -->
            <workflow-config-role-add ref="workflowConfigRoleAdd" @refreshDataList="table.query"/>
          </zt-table-wraper>
</template>

<script>
import workflowConfigRoleAdd from './workflow-config-role-add'
import qs from 'qs'
import Cookies from 'js-cookie'

export default {
  data() {
    return {
      dataForm: {
        id: '',
        roleId: '',
      },
      defList: [],
      selectedWorkflowConfigFlag: false,
    }
  },
  components: {
    workflowConfigRoleAdd
  },
  methods: {
    initTable(id) {
      if (id) {
        this.dataForm.id = id
        this.$refs.tableObj.query()
        this.selectedWorkflowConfigFlag = true
      } else {
        this.selectedWorkflowConfigFlag = false
        this.$refs.tableObj.dataList = []
      }
    },
    addRole(id) {
      this.$refs.workflowConfigRoleAdd.$refs.dialog.init(id)
    },
    async deleteHandle() {
      let dataIds = []
      for (let val of this.$refs.tableObj.dataSelectedList) {
        dataIds.push(val.stepId)
      }
      let roleIds = []
      for (let val of this.$refs.tableObj.dataSelectedList) {
        roleIds.push(val.roleId)
      }
      console.log(roleIds.length)
      if (dataIds.length <= 0) {
        this.$tip.alert('请勾选要删除的数据')
      } else {
        if (await this.$tip.confirm(dataIds.length > 0 ? '是否删除【勾选】的数据?' : '是否删除所有【满足条件】的数据', '提示')) {
          let ids = ''
          for (let val of this.$refs.tableObj.dataSelectedList) {
            ids = val.stepId
          }
          for (let val of this.$refs.tableObj.dataSelectedList) {
            this.dataForm.roleId = this.dataForm.roleId + val.roleId + ','
          }
          let params = qs.stringify({
            'token': Cookies.get('token'),
            'stepId': ids,
            'roleId': this.dataForm.roleId,
          })
          let res = await this.$http.get(`/workflowConfig/deleteWorkflowStepsRole?${params}`)
          if (res.success) {
            await this.$tip.success()
            this.$refs.tableObj.query()
          }
        }
      }
    },
  }
}
</script>
